pub struct Table { /* private fields */ }Implementations
Sourceimpl Table
impl Table
pub fn new( title: String, rows: i16, border_color: Option<Color>, title_color: Option<Color>, data: Option<Vec<Vec<String>>>, ) -> Self
Sourcepub fn with_column_count_override(self, columns: i16) -> Self
pub fn with_column_count_override(self, columns: i16) -> Self
Override the default column count This is not recommended, but can be used with cautious amounts of columns because of terminal width restrictions.
pub fn render(&self) -> Result<(), Box<dyn Error>>